@@ -1,3 +1,4 @@
+import os
 from yape.log import yape_log
 from yape.utils import run_python_module, option_or_empty, clean_args
 from yape.config import YAPEConfig
@@ -26,3 +27,10 @@ def virtualenv_create(config: YAPEConfig):
     cmnd = ["virtualenv", *virtualenv_args(config)]
     yape_log.debug(str(cmnd))
     run_python_module(*cmnd, use_vevn=False)
+
+    if config.pip_config_path is not None:
+        config_path = config.resolve_from_source_directory(config.pip_config_path)
+        if not os.path.isfile(config_path):
+            yape_log.warn("Could not set custom config path, pip_config_path not found @ " + config_path)
+        else:
+            os.symlink(config_path, config.resolve_from_venv_directory("pip.conf"))
